@@ -5,10 +5,11 @@ from django.utils.translation import ugettext_lazy as _
 from tendenci.addons.make_payments.models import MakePayment
 from tendenci.core.base.fields import EmailVerificationField
 #from captcha.fields import CaptchaField
-from simplemathcaptcha.fields import MathCaptchaField
+#from simplemathcaptcha.fields import MathCaptchaField
+from tendenci.core.base.forms import SimpleMathField
 
 class MakePaymentForm(forms.ModelForm):
-    captcha = MathCaptchaField(help_text=_("Please fill in the letters in the image"))
+    captcha = SimpleMathField()
     # TODO: Make check-paid an admin only option
     payment_method = forms.CharField(widget=forms.RadioSelect(choices=(('cc', 'Make Online Payment'),)), initial='cc',)
     company = forms.CharField(max_length=50, required=False, widget=forms.TextInput(attrs={'size':'30'}))
